Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1184)

Unified Diff: ui/events/ozone/evdev/event_converter_evdev_impl.h

Issue 992323004: [Ozone] Fix disabling keyboard in maximized mode (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Created 5 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | ui/events/ozone/evdev/event_converter_evdev_impl.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: ui/events/ozone/evdev/event_converter_evdev_impl.h
diff --git a/ui/events/ozone/evdev/event_converter_evdev_impl.h b/ui/events/ozone/evdev/event_converter_evdev_impl.h
index f0f0b8aff5c1087aace0532750dc780210f5e43e..cc54229221645720ddf9cc172257368aa1201e25 100644
--- a/ui/events/ozone/evdev/event_converter_evdev_impl.h
+++ b/ui/events/ozone/evdev/event_converter_evdev_impl.h
@@ -5,7 +5,7 @@
#ifndef UI_EVENTS_OZONE_EVDEV_EVENT_CONVERTER_EVDEV_IMPL_H_
#define UI_EVENTS_OZONE_EVDEV_EVENT_CONVERTER_EVDEV_IMPL_H_
-#include <set>
+#include <bitset>
#include "base/files/file_path.h"
#include "base/message_loop/message_pump_libevent.h"
@@ -80,9 +80,8 @@ class EVENTS_OZONE_EVDEV_EXPORT EventConverterEvdevImpl
// Controller for watching the input fd.
base::MessagePumpLibevent::FileDescriptorWatcher controller_;
- // The keys which should be processed. nullptr if all keys should be
- // processed.
- scoped_ptr<std::set<DomCode>> allowed_keys_;
+ // The evdev codes of the keys which should be blocked.
+ std::bitset<KEY_CNT> blocked_keys_;
// Pressed keys bitset.
std::bitset<KEY_CNT> key_state_;
« no previous file with comments | « no previous file | ui/events/ozone/evdev/event_converter_evdev_impl.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698